@@ -40,4 +40,16 @@ hotpatch_binding <- function(binding, fn, env) {
 .onLoad <- function(...) {
   maybe_hotpatch_dplyr()
   setHook(packageEvent("dplyr", "onLoad"), maybe_hotpatch_dplyr)
+
+  local(envir = ns_env("tidyselect"), {
+    delayedAssign("signal", {
+      if (utils::packageVersion("rlang") < "0.2.99") {
+        function(message, .subclass) {
+          cnd_signal(.subclass)
+        }
+      } else {
+        env_get(ns_env("rlang"), "signal")
+      }
+    })
+  })
 }
