@@ -43,10 +43,12 @@ test_that("symbol overscope works with parenthesised expressions", {
 test_that("can select with unnamed elements", {
   expect_identical(vars_select(c("a", ""), a), c(a = "a"))
   expect_identical(vars_select(c("a", NA), a), c(a = "a"))
+  expect_identical(vars_select(c("", "a"), a), c(a = "a"))
+  expect_identical(vars_select(c(NA, "a"), a), c(a = "a"))
 })
 
 test_that("can customise error messages", {
-  vars <- set_attrs(letters, type = c("variable", "variables"))
+  vars <- structure(letters, type = c("variable", "variables"))
 
   expect_error(vars_select(vars, "foo"), "Unknown variable `foo`")
   expect_warning(vars_select(vars, one_of("bim")), "Unknown variables:")
@@ -64,6 +66,11 @@ test_that("can supply empty inputs", {
   expect_identical(vars_select(letters, a, chr()), c(a = "a"))
 })
 
+test_that("empty selection signals a condition", {
+  expect_is(catch_cnd(vars_select(letters)), "tidyselect_empty_dots")
+  expect_is(catch_cnd(vars_select(letters, starts_with("1"))), "tidyselect_empty")
+})
+
 test_that("unknown variables errors are ignored if `.strict` is FALSE", {
   expect_identical(vars_select(letters, `_foo`, .strict = FALSE), set_names(chr()))
   expect_identical(vars_select(letters, a, `_foo`, .strict = FALSE), c(a = "a"))
@@ -102,3 +109,7 @@ test_that("vars_select() handles named character vectors", {
   expect_identical(vars_select(letters, c("A" = "y", "B" = "z")), vars_select(letters, A = y, B = z))
   expect_identical(vars_select(letters, !! c("A" = "y", "B" = "z")), vars_select(letters, A = y, B = z))
 })
+
+test_that("can select with length > 1 double vectors (#43)", {
+  expect_identical(vars_select(letters, !!c(1, 2)), c(a = "a", b = "b"))
+})
